==> tasks-v1.8.8.zip: tasks/messages/it/base.php <==
<?php

return [
    '1 Day before' => '1 giorno prima',
    '1 Month before' => '1 mese prima',
    '1 Week before' => '1 settimana prima',
    '2 Days before' => '2 giorni prima',
    '2 Weeks before' => '2 settimane prima',
    '3 Weeks before' => '3 settimane prima',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Gli utenti assegnati </strong> possono processare questa attività.',
    '<strong>Confirm</strong> task deletion' => '<strong>Conferma</strong> eliminazione attività',
    '<strong>Create</strong> task list' => '<strong>Crea</strong> lista di attività',
    '<strong>Edit</strong> task' => '<strong>Modifica</strong> attività',
    '<strong>Edit</strong> task list' => '<strong>Modifica</strong> lista di attività',
    '<strong>New</strong> Task' => '<strong>Nuova</strong> Attività',
    '<strong>Task</strong> Overview' => 'Panoramica <strong>Attività</strong>',
    '<strong>Tasks</strong>' => '<strong>Attività</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configurazione del modulo <strong>Tasks</strong>',
    '<strong>Your</strong> tasks' => '<strong>Le tue</strong> attività',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Un widget è un elemento aggiunto alla barra laterale di uno stream. In questo caso fornisce agli utenti una breve panoramica delle loro attività.',
    'Accept Task' => 'Accetta attività',
    'Add Deadline to space calendar' => 'Aggiungi scadenza al calendario dello spazio',
    'Add checkpoint...' => 'Aggiungi a checklist...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Aggiungi punti di controllo all\'attività per evidenziare i singoli passaggi necessari per completarla.',
    'Add entry to main navigation' => 'Aggiungi voce alla navigazione principale',
    'Add reminder' => 'Aggiungi promemoria',
    'Add responsible users' => 'Aggiungi responsabili',
    'Add schedule to the space calendar' => 'Aggiungi schedulazione al calendario dello spazio',
    'Add task' => 'Aggiungi attività',
    'Add to space calendar' => 'Aggiungi al calendario dello spazio',
    'Additional options' => 'Opzioni aggiuntive',
    'All Day' => 'Tutto il giorno',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permette all\'utente di creare nuove attività, l\'utente sarà solo in grado di modificare ed eliminare le proprie attività.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permetti agli utenti di creare, eliminare e modificare attività, liste di attività, riordinare attività e liste',
    'Allows the user to process unassigned tasks' => 'Permetti agli utenti di eseguire attività non assegnate',
    'Already requested' => 'Già richiesta',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Qualsiasi utente con i permessi può eseguire questa attività',
    'Anyone can work on this task!' => 'Tutti possono eseguire questa attività!',
    'Assign myself' => 'Assegna me stesso',
    'Assign users' => 'Assegna utenti',
    'Assigned' => 'Assegnata',
    'Assigned users' => 'Utenti assegnati',
    'Assignment' => 'Assegnazioni',
    'Assignments:' => 'Assegnazioni:',
    'At least 1 Hour before' => 'almeno 1 ora prima',
    'At least 2 Hours before' => 'almeno 2 ore prima',
    'Attachments' => 'Allegati',
    'Begin Task' => 'Inizia attività',
    'Checklist Items' => 'Elenco checklist',
    'Checklist:' => 'Checklist:',
    'Checkpoints' => 'Punti di controllo',
    'Choose if you want the module to appear in the main navigation.' => 'Scegli se vuoi che il modulo appaia nella navigazione principale.',
    'Close' => 'Chiudi',
    'Color' => 'Colore',
    'Completed' => 'Completata',
    'Completed lists' => 'Liste completate',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configura il modulo Attività per soddisfare i tuoi requisiti e bisogni specifici. È possibile definire impostazioni individuali e, ad esempio, decidere se visualizzare un widget.',
    'Continue Review' => 'Continua revisione',
    'Create tasks' => 'Crea attività',
    'Created by me' => 'Creato da me',
    'Date' => 'Data',
    'Deadline at' => 'Scadenza il',
    'Deadline: ' => 'Scadenza:',
    'Delete' => 'Cancella',
    'Delete list' => 'Elimina lista',
    'Description' => 'Descrizione',
    'Do not remind' => 'Nessun promemoria',
    'Do you really want to delete this task?' => 'Vuoi veramente eliminare questa attività?',
    'Don\'t add to calendar' => 'Non aggiungere al calendario',
    'Drag entry' => 'Sposta',
    'Edit' => 'modifica',
    'Edit item (empty field will be removed)...' => 'Modifica elemento (i campi vuoti saranno rimossi)',
    'Edit list' => 'modifica lista',
    'End' => 'Fine',
    'End Date' => 'Data di fine',
    'End Time' => 'Orario di fine',
    'End date' => 'Data fine',
    'End time must be after start time!' => 'L\'orario di fine deve essere dopo l\'orario di inizio!',
    'Extend deadline request' => 'Richiedi estensione scadenza',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtra per stato',
    'Filter by title' => 'Filtra per titolo',
    'Filter tasks' => 'Filtra attività',
    'Finish Task' => 'Concludi attività',
    'General' => 'Generale',
    'General Settings' => 'Impostazioni generali',
    'Hide this list once all tasks are completed' => 'Nascondi questa lista finchè tutte le attività saranno completate',
    'I\'m assigned' => 'Assegnato a me',
    'I\'m responsible' => 'Sono il responsabile',
    'If empty any user can complete the task.' => 'Se vuoto, qualsiasi utente può completare l\'attività.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se non viene selezionato alcun utente assegnato, ogni membro dello spazio con il permesso di processare attività non assegnate può elaborare l\'attività.',
    'In Progress' => 'In corso',
    'In Review' => 'In revisione',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Nel caso in cui l\'opzione di revisione sia attiva, un <strong> utente responsabile  strong&gt; dovrà esaminare e rifiutare o confermare questa attività prima del completamento.</strong>',
    'Invalid task list selection.' => 'Selezione elenco attività non valida.',
    'Let Task Review' => 'Revisiona l\'attività',
    'Main Navigation' => 'Navigazione principale',
    'Manage tasks' => 'Gestisci attività',
    'Maximum number of entries in widget' => 'Numero massimo di voci nel widget',
    'Module Widget' => 'Widget del modulo',
    'New list or search' => 'Nuovo elenco o ricerca',
    'No Scheduling set for this Task' => 'Nessuna schedulazione impostata per questa attività',
    'No pending tasks found' => 'Nessuna attività in sospeso trovata',
    'No results found for the given filter.' => 'Nessun risultato per il filtro impostato.',
    'Open Task' => 'Attività aperta',
    'Other Tasks' => 'Altre attività',
    'Overdue' => 'Scaduta',
    'Overview' => 'Panoramica',
    'Parent Task' => 'Attività principale',
    'Pending' => 'In attesa',
    'Pending Review' => 'In attesa di revisione',
    'Process unassigned tasks' => 'esegui attività non assegnate',
    'Ready For Review' => 'Pronta per revisione',
    'Receive Notifications for Task Reminder.' => 'Ricevi notifiche per i promemoria delle attività',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Ricevi notifiche per le attività (aggiornamenti, scadenze e modifiche).',
    'Reject Task' => 'Rifiunta attività',
    'Remind Mode' => 'Modo di promemoria',
    'Reminder' => 'Promemoria',
    'Reminder sent' => 'Promemoria inviato',
    'Reminders' => 'Promemoria',
    'Request extension' => 'Richiedi estensione',
    'Request sent' => 'Richiesta inviata',
    'Reset Task' => 'Ricomincia attività',
    'Responsible' => 'Responsabile',
    'Responsible users' => 'Utenti responsabili',
    'Review by responsible user required' => 'Necessaria revisione da un utente responsabile',
    'Scheduling' => 'Schedulazione',
    'Show widget in Spaces' => 'Mostra widget in Spazi',
    'Show widget on Dashboard' => 'Mostra widget su Dashboard',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostra {countTasks,plural,=1{# altra attività} other{# altre attività}}',
    'Sort Order' => 'Cambia ordnie',
    'Sort order' => 'Ordinamento',
    'Spaces' => 'Space',
    'Start' => 'Inizio',
    'Start Date' => 'Data di inizio',
    'Start Time' => 'Orario di inizio',
    'Start date' => 'Data inizio',
    'Starting at' => 'A partire da',
    'Status' => 'Stato',
    'Task' => 'Attività',
    'Task List' => 'Elenco attività dashboard',
    'Task Users have been notified' => 'Gli utenti sono stati notificati dell\'attività',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'L\' attività {task} nello spazio {spaceName} finisce il {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'L\' attività {task} nello spazio {spaceName} inizia il {dateTime}.',
    'Tasks' => 'Attività',
    'Tasks: Reminder' => 'Promemoria attività',
    'This task can only be processed by assigned and responsible users.' => 'Questa attività può essere eseguita da assegnatari e responsabili.',
    'This task requires to be reviewed by a responsible' => 'Questa attività necessita la revisione di un responsabile',
    'Time Zone' => 'Fuso orario',
    'Title' => 'Titolo',
    'Title and Color' => 'Titolo e colore',
    'Title of your task list' => 'Titolo della tua lista di attività',
    'Today' => 'Oggi',
    'Unsorted' => 'Non ordinate',
    'View Online' => 'Vedi online',
    'You are assigned!' => 'Assegnata a te!',
    'You are responsible!' => 'Sei il responsabile!',
    'You have insufficient permissions to perform that operation!' => 'Non hai il permesso per eseguire questa operazione!',
    'Your Reminder for task {task}' => 'Il tuo promemoria per l\'attività {task}',
    'ending Review' => 'Completa revisione',
    'view all' => 'visualizza tutti',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# giorno rimanente} other{# giorni rimanenti}}',
    '{displayName} is assigned to this task' => '{displayName} è assegnato a questa attività',
    '{displayName} is responsible for this task' => '{displayName} è il responsabile di questa attività',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} ti ha designato come responsabile per l\'attività {task} nello spazio {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ti ha assegnato l\'attività {task} nello spazio {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} ha completato l\'attività {task} nello spazio {spaceName}.',
    '{userName} completed task {task}.' => '{userName} ha completato l\'attività {task}.',
    '{userName} finished task {task}.' => '{userName} ha completato l\'attività {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ha modificato la scadenza per l\'attività {task} nello spazio {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} riaperto l\'attività {task} nello spazio {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ha rifiutato l\'attività {task} nello spazio {spaceName}.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} ha completato l\'attività {task} nello spazio {spaceName}.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} richiesto un\' estensione di scadenza per l\'attività {task} nello spazio {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} richiede di revisionare l\'attività {task} nello spazio {spaceName}.',
    '{userName} reset task {task}.' => '{userName} ha ricominciato l\'attività {task}.',
    '{userName} reviewed task {task}.' => '{userName} ha revisionato l\'attività {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} inizitato l\'attività {task} nello spazio {spaceName}.',
    '{userName} works on task {task}.' => '{userName} sta eseguendo l\'attività {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/it/base.php <==
<?php

return [
    '1 Day before' => '1 giorno prima',
    '1 Month before' => '1 mese prima',
    '1 Week before' => '1 settimana prima',
    '2 Days before' => '2 giorni prima',
    '2 Weeks before' => '2 settimane prima',
    '3 Weeks before' => '3 settimane prima',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Gli utenti assegnati </strong> possono processare questa attività.',
    '<strong>Confirm</strong> task deletion' => '<strong>Conferma</strong> eliminazione attività',
    '<strong>Create</strong> task list' => '<strong>Crea</strong> lista di attività',
    '<strong>Edit</strong> task' => '<strong>Modifica</strong> attività',
    '<strong>Edit</strong> task list' => '<strong>Modifica</strong> lista di attività',
    '<strong>New</strong> Task' => '<strong>Nuova</strong> Attività',
    '<strong>Task</strong> Overview' => 'Panoramica <strong>Attività</strong>',
    '<strong>Tasks</strong>' => '<strong>Attività</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configurazione del modulo <strong>Tasks</strong>',
    '<strong>Your</strong> tasks' => '<strong>Le tue</strong> attività',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Un widget è un elemento aggiunto alla barra laterale di uno stream. In questo caso fornisce agli utenti una breve panoramica delle loro attività.',
    'Accept Task' => 'Accetta attività',
    'Add Deadline to space calendar' => 'Aggiungi scadenza al calendario dello spazio',
    'Add checkpoint...' => 'Aggiungi a checklist...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Aggiungi punti di controllo all\'attività per evidenziare i singoli passaggi necessari per completarla.',
    'Add entry to main navigation' => 'Aggiungi voce alla navigazione principale',
    'Add reminder' => 'Aggiungi promemoria',
    'Add responsible users' => 'Aggiungi responsabili',
    'Add schedule to the space calendar' => 'Aggiungi schedulazione al calendario dello spazio',
    'Add task' => 'Aggiungi attività',
    'Add to space calendar' => 'Aggiungi al calendario dello spazio',
    'Additional options' => 'Opzioni aggiuntive',
    'All Day' => 'Tutto il giorno',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permette all\'utente di creare nuove attività, l\'utente sarà solo in grado di modificare ed eliminare le proprie attività.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permetti agli utenti di creare, eliminare e modificare attività, liste di attività, riordinare attività e liste',
    'Allows the user to process unassigned tasks' => 'Permetti agli utenti di eseguire attività non assegnate',
    'Already requested' => 'Già richiesta',
    'Assign myself' => 'Assegna me stesso',
    'Assign users' => 'Assegna utenti',
    'Assigned users' => 'Utenti assegnati',
    'Assignment' => 'Assegnazioni',
    'At least 1 Hour before' => 'almeno 1 ora prima',
    'At least 2 Hours before' => 'almeno 2 ore prima',
    'Attachments' => 'Allegati',
    'Begin Task' => 'Inizia attività',
    'Checklist Items' => 'Elenco checklist',
    'Checklist:' => 'Checklist:',
    'Checkpoints' => 'Punti di controllo',
    'Choose if you want the module to appear in the main navigation.' => 'Scegli se vuoi che il modulo appaia nella navigazione principale.',
    'Close' => 'Chiudi',
    'Color' => 'Colore',
    'Completed' => 'Completata',
    'Completed lists' => 'Liste completate',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configura il modulo Attività per soddisfare i tuoi requisiti e bisogni specifici. È possibile definire impostazioni individuali e, ad esempio, decidere se visualizzare un widget.',
    'Continue Review' => 'Continua revisione',
    'Create tasks' => 'Crea attività',
    'Created by me' => 'Creato da me',
    'Date' => 'Data',
    'Deadline: ' => 'Scadenza:',
    'Delete' => 'Cancella',
    'Delete list' => 'Elimina lista',
    'Description' => 'Descrizione',
    'Do not remind' => 'Nessun promemoria',
    'Do you really want to delete this task?' => 'Vuoi veramente eliminare questa attività?',
    'Don\'t add to calendar' => 'Non aggiungere al calendario',
    'Edit' => 'modifica',
    'Edit item (empty field will be removed)...' => 'Modifica elemento (i campi vuoti saranno rimossi)',
    'Edit list' => 'modifica lista',
    'End' => 'Fine',
    'End Date' => 'Data di fine',
    'End Time' => 'Orario di fine',
    'End date' => 'Data fine',
    'End time must be after start time!' => 'L\'orario di fine deve essere dopo l\'orario di inizio!',
    'Extend deadline request' => 'Richiedi estensione scadenza',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtra per stato',
    'Filter by title' => 'Filtra per titolo',
    'Filter tasks' => 'Filtra attività',
    'Finish Task' => 'Concludi attività',
    'General' => 'Generale',
    'General Settings' => 'Impostazioni generali',
    'Hide this list once all tasks are completed' => 'Nascondi questa lista finchè tutte le attività saranno completate',
    'I\'m assigned' => 'Assegnato a me',
    'I\'m responsible' => 'Sono il responsabile',
    'If empty any user can complete the task.' => 'Se vuoto, qualsiasi utente può completare l\'attività.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se non viene selezionato alcun utente assegnato, ogni membro dello spazio con il permesso di processare attività non assegnate può elaborare l\'attività.',
    'In Progress' => 'In corso',
    'In Review' => 'In revisione',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Nel caso in cui l\'opzione di revisione sia attiva, un <strong> utente responsabile  strong&gt; dovrà esaminare e rifiutare o confermare questa attività prima del completamento.</strong>',
    'Invalid task list selection.' => 'Selezione elenco attività non valida.',
    'Let Task Review' => 'Revisiona l\'attività',
    'Main Navigation' => 'Navigazione principale',
    'Manage tasks' => 'Gestisci attività',
    'Maximum number of entries in widget' => 'Numero massimo di voci nel widget',
    'Module Widget' => 'Widget del modulo',
    'New list or search' => 'Nuovo elenco o ricerca',
    'No Scheduling set for this Task' => 'Nessuna schedulazione impostata per questa attività',
    'No pending tasks found' => 'Nessuna attività in sospeso trovata',
    'No results found for the given filter.' => 'Nessun risultato per il filtro impostato.',
    'Open Task' => 'Attività aperta',
    'Other Tasks' => 'Altre attività',
    'Overdue' => 'Scaduta',
    'Overview' => 'Panoramica',
    'Parent Task' => 'Attività principale',
    'Pending' => 'In attesa',
    'Pending Review' => 'In attesa di revisione',
    'Process unassigned tasks' => 'esegui attività non assegnate',
    'Ready For Review' => 'Pronta per revisione',
    'Receive Notifications for Task Reminder.' => 'Ricevi notifiche per i promemoria delle attività',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Ricevi notifiche per le attività (aggiornamenti, scadenze e modifiche).',
    'Reject Task' => 'Rifiunta attività',
    'Remind Mode' => 'Modo di promemoria',
    'Reminder' => 'Promemoria',
    'Reminder sent' => 'Promemoria inviato',
    'Reminders' => 'Promemoria',
    'Request extension' => 'Richiedi estensione',
    'Request sent' => 'Richiesta inviata',
    'Reset Task' => 'Ricomincia attività',
    'Responsible' => 'Responsabile',
    'Responsible users' => 'Utenti responsabili',
    'Review by responsible user required' => 'Necessaria revisione da un utente responsabile',
    'Scheduling' => 'Schedulazione',
    'Show widget in Spaces' => 'Mostra widget in Spazi',
    'Show widget on Dashboard' => 'Mostra widget su Dashboard',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostra {countTasks,plural,=1{# altra attività} other{# altre attività}}',
    'Sort Order' => 'Cambia ordnie',
    'Sort order' => 'Ordinamento',
    'Spaces' => 'Space',
    'Start' => 'Inizio',
    'Start Date' => 'Data di inizio',
    'Start Time' => 'Orario di inizio',
    'Start date' => 'Data inizio',
    'Starting at' => 'A partire da',
    'Status' => 'Stato',
    'Task' => 'Attività',
    'Task List' => 'Elenco attività dashboard',
    'Task Users have been notified' => 'Gli utenti sono stati notificati dell\'attività',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'L\' attività {task} nello spazio {spaceName} finisce il {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'L\' attività {task} nello spazio {spaceName} inizia il {dateTime}.',
    'Tasks' => 'Attività',
    'Tasks: Reminder' => 'Promemoria attività',
    'This task requires to be reviewed by a responsible' => 'Questa attività necessita la revisione di un responsabile',
    'Time Zone' => 'Fuso orario',
    'Title' => 'Titolo',
    'Title and Color' => 'Titolo e colore',
    'Title of your task list' => 'Titolo della tua lista di attività',
    'Today' => 'Oggi',
    'Unsorted' => 'Non ordinate',
    'View Online' => 'Vedi online',
    'You have insufficient permissions to perform that operation!' => 'Non hai il permesso per eseguire questa operazione!',
    'Your Reminder for task {task}' => 'Il tuo promemoria per l\'attività {task}',
    'view all' => 'visualizza tutti',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# giorno rimanente} other{# giorni rimanenti}}',
    '{displayName} is assigned to this task' => '{displayName} è assegnato a questa attività',
    '{displayName} is responsible for this task' => '{displayName} è il responsabile di questa attività',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} ti ha designato come responsabile per l\'attività {task} nello spazio {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ti ha assegnato l\'attività {task} nello spazio {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} ha completato l\'attività {task} nello spazio {spaceName}.',
    '{userName} completed task {task}.' => '{userName} ha completato l\'attività {task}.',
    '{userName} finished task {task}.' => '{userName} ha completato l\'attività {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ha modificato la scadenza per l\'attività {task} nello spazio {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} riaperto l\'attività {task} nello spazio {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ha rifiutato l\'attività {task} nello spazio {spaceName}.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} ha completato l\'attività {task} nello spazio {spaceName}.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} richiesto un\' estensione di scadenza per l\'attività {task} nello spazio {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} richiede di revisionare l\'attività {task} nello spazio {spaceName}.',
    '{userName} reset task {task}.' => '{userName} ha ricominciato l\'attività {task}.',
    '{userName} reviewed task {task}.' => '{userName} ha revisionato l\'attività {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} inizitato l\'attività {task} nello spazio {spaceName}.',
    '{userName} works on task {task}.' => '{userName} sta eseguendo l\'attività {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
